PyXMake Developer Guide: PyXMake.VTL.stm_make.doxy_mcdpycodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Protected Attributes | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.doxy_mcdpycodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.doxy_mcdpycodac:

## Public Attributes
str | brief = "PyCODAC"
str | header = "PyCODAC Developer Guide"
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | stype = "Fortran"
| scratch_path = os.getcwd()
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_doxygen
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Protected Attributes
list | _INPUT_FILES

## Static Protected Attributes
str | _BUILD_NAME = 'pyc_core'
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
str | _BUILD_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_doxygen
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
str | description = "Runs the html documentation build process of source code using Doxygen."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the html documentation build process for PyCODAC.

Definition at line 454 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.doxy_mcdpycodac._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 461 of file stm_make.py.

## Member Data Documentation

## ◆ _BUILD_NAME

str PyXMake.VTL.stm_make.doxy_mcdpycodac._BUILD_NAME = 'pyc_core'
| staticprotected

Definition at line 459 of file stm_make.py.

## ◆ _INPUT_FILES

list PyXMake.VTL.stm_make.doxy_mcdpycodac._INPUT_FILES
| protected

Initial value:
= [x[0] for x in Utility.PathWalk(self.source_path, startswith=(".","__"),
contains=("DELiS","Smetana","PyXMake","external","doc","cmd","bin","include","lib","config","fetch"),
endswith=("VTL","make","scratch","examples","src","config","solver"))]

Definition at line 464 of file stm_make.py.

## ◆ brief

str PyXMake.VTL.stm_make.doxy_mcdpycodac.brief = "PyCODAC"

Definition at line 468 of file stm_make.py.

## ◆ header

str PyXMake.VTL.stm_make.doxy_mcdpycodac.header = "PyCODAC Developer Guide"

Definition at line 469 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py